# Discovering MCP Servers from Microsoft Azure API Center
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/discovering-mcp-servers-from-microsoft-azure-api-center#overview)
  * [Scope](https://help.sap.com/docs/leanix/ea/discovering-mcp-servers-from-microsoft-azure-api-center#scope)
  * [Prerequisites](https://help.sap.com/docs/leanix/ea/discovering-mcp-servers-from-microsoft-azure-api-center#prerequisites)
  * [MCP Server Details](https://help.sap.com/docs/leanix/ea/discovering-mcp-servers-from-microsoft-azure-api-center#mcp-server-details)
  * [Step 1: Register SAP LeanIX in Microsoft Entra ID](https://help.sap.com/docs/leanix/ea/discovering-mcp-servers-from-microsoft-azure-api-center#step-1:-register-sap-leanix-in-microsoft-entra-id)
  * [Step 2: Grant Permissions to SAP LeanIX](https://help.sap.com/docs/leanix/ea/discovering-mcp-servers-from-microsoft-azure-api-center#step-2:-grant-permissions-to-sap-leanix)
  * [Step 3: Gather Configuration Credentials](https://help.sap.com/docs/leanix/ea/discovering-mcp-servers-from-microsoft-azure-api-center#step-3:-gather-configuration-credentials)
  * [Step 4: Connect SAP LeanIX to Microsoft Azure API Center](https://help.sap.com/docs/leanix/ea/discovering-mcp-servers-from-microsoft-azure-api-center#step-4:-connect-sap-leanix-to-microsoft-azure-api-center)


View all
Discover your MCP servers registered in Microsoft Azure API Center. Review discovered items and add them to your inventory in SAP LeanIX.
